@@ -221,7 +221,7 @@ void UMLDragData::setUMLDataClip4(UMLObjectList& objects, UMLWidgetList& widgets
     setData(QLatin1String("application/x-uml-clip4"), domDoc.toString().toUtf8());
 
     QImage img = pngImage.toImage();
-    int l_size = img.numBytes();
+    int l_size = img.byteCount();
     QByteArray clipdata;
     clipdata.resize(l_size);
     QDataStream clipstream(&clipdata, QIODevice::WriteOnly);
@@ -549,7 +549,7 @@ bool UMLDragData::decodeClip4(const QMimeData* mimeData, UMLObjectList& objects,
             }
 
             // check if widget is pastable
-            if (sourceView->umlScene()->type() != scene->type()) {
+            if (!sourceView || sourceView->umlScene()->type() != scene->type()) {
                 UMLObject *object = widget->umlObject();
                 if (object) {
                     if (!Model_Utils::typeIsAllowedInDiagram(object, scene)) {
@@ -881,4 +881,3 @@ int UMLDragData::getCodingType(const QMimeData* mimeData)
     return result;
 }
 
-#include "umldragdata.moc"
